import datetime

__author__ = "PG"
__version__ = "1.0.1"
__description__ = "The Modern en/de-cryption CLI utility"
__copyright__ = f"Copyright {datetime.date.today().year} PG"
__github__ = "https://github.com/Programming-geek582/encipher"
__email__ = "htmlgeek752@gmail.com"
